ZSTD_CCtx typedef

ZSTD_CCtx = ZSTD_CCtx_s

Explicit context / /*= Compression context When compressing many times, it is recommended to allocate a compression context just once, and reuse it for each successive compression operation. This will make the workload easier for system's memory. Note : re-using context is just a speed / resource optimization. It doesn't change the compression ratio, which remains identical. Note 2: For parallel execution in multi-threaded environments, use one different context per thread .

Implementation

typedef ZSTD_CCtx = ZSTD_CCtx_s;