ZSTD_EndDirective enum

===== Streaming compression functions =====

Inheritance
Available extensions

Values

ZSTD_e_continue → const ZSTD_EndDirective

collect more data, encoder decides when to output compressed result, for optimal compression ratio

const ZSTD_EndDirective(0)
ZSTD_e_flush → const ZSTD_EndDirective

flush any data provided so far, it creates (at least) one new block, that can be decoded immediately on reception; frame will continue: any future data can still reference previously compressed data, improving compression. note : multithreaded compression will block to flush as much output as possible.

const ZSTD_EndDirective(1)
ZSTD_e_end → const ZSTD_EndDirective

flush any remaining data and close current frame. note that frame is only closed after compressed data is fully flushed (return value == 0). After that point, any additional data starts a new frame. note : each frame is independent (does not reference any content from previous frame). : note : multithreaded compression will block to flush as much output as possible.

const ZSTD_EndDirective(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ZSTD_EndDirective

Constants

values → const List<ZSTD_EndDirective>
A constant List of the values in this enum, in order of their declaration.