ZSTD_ErrorCode enum

-********************************************* Error codes list -********************************************* Error codes values are pinned down since v1.3.1 only. Therefore, don't rely on values if you may link to any version < v1.3.1.

Only values < 100 are considered stable.

note 1 : this API shall be used with static linking only. dynamic linking is not yet officially supported. note 2 : Prefer relying on the enum than on its value whenever possible This is the only supported way to use the error list < v1.3.1 note 3 : ZSTD_isError() is always correct, whatever the library version.

Inheritance
Available extensions

Values

ZSTD_error_no_error → const ZSTD_ErrorCode
const ZSTD_ErrorCode(0)
ZSTD_error_GENERIC → const ZSTD_ErrorCode
const ZSTD_ErrorCode(1)
ZSTD_error_prefix_unknown → const ZSTD_ErrorCode
const ZSTD_ErrorCode(10)
ZSTD_error_version_unsupported → const ZSTD_ErrorCode
const ZSTD_ErrorCode(12)
ZSTD_error_frameParameter_unsupported → const ZSTD_ErrorCode
const ZSTD_ErrorCode(14)
ZSTD_error_frameParameter_windowTooLarge → const ZSTD_ErrorCode
const ZSTD_ErrorCode(16)
ZSTD_error_corruption_detected → const ZSTD_ErrorCode
const ZSTD_ErrorCode(20)
ZSTD_error_checksum_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(22)
ZSTD_error_literals_headerWrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(24)
ZSTD_error_dictionary_corrupted → const ZSTD_ErrorCode
const ZSTD_ErrorCode(30)
ZSTD_error_dictionary_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(32)
ZSTD_error_dictionaryCreation_failed → const ZSTD_ErrorCode
const ZSTD_ErrorCode(34)
ZSTD_error_parameter_unsupported → const ZSTD_ErrorCode
const ZSTD_ErrorCode(40)
ZSTD_error_parameter_combination_unsupported → const ZSTD_ErrorCode
const ZSTD_ErrorCode(41)
ZSTD_error_parameter_outOfBound → const ZSTD_ErrorCode
const ZSTD_ErrorCode(42)
ZSTD_error_tableLog_tooLarge → const ZSTD_ErrorCode
const ZSTD_ErrorCode(44)
ZSTD_error_maxSymbolValue_tooLarge → const ZSTD_ErrorCode
const ZSTD_ErrorCode(46)
ZSTD_error_maxSymbolValue_tooSmall → const ZSTD_ErrorCode
const ZSTD_ErrorCode(48)
ZSTD_error_cannotProduce_uncompressedBlock → const ZSTD_ErrorCode
const ZSTD_ErrorCode(49)
ZSTD_error_stabilityCondition_notRespected → const ZSTD_ErrorCode
const ZSTD_ErrorCode(50)
ZSTD_error_stage_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(60)
ZSTD_error_init_missing → const ZSTD_ErrorCode
const ZSTD_ErrorCode(62)
ZSTD_error_memory_allocation → const ZSTD_ErrorCode
const ZSTD_ErrorCode(64)
ZSTD_error_workSpace_tooSmall → const ZSTD_ErrorCode
const ZSTD_ErrorCode(66)
ZSTD_error_dstSize_tooSmall → const ZSTD_ErrorCode
const ZSTD_ErrorCode(70)
ZSTD_error_srcSize_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(72)
ZSTD_error_dstBuffer_null → const ZSTD_ErrorCode
const ZSTD_ErrorCode(74)
ZSTD_error_noForwardProgress_destFull → const ZSTD_ErrorCode
const ZSTD_ErrorCode(80)
ZSTD_error_noForwardProgress_inputEmpty → const ZSTD_ErrorCode
const ZSTD_ErrorCode(82)
ZSTD_error_frameIndex_tooLarge → const ZSTD_ErrorCode

following error codes are NOT STABLE, they can be removed or changed in future versions

const ZSTD_ErrorCode(100)
ZSTD_error_seekableIO → const ZSTD_ErrorCode
const ZSTD_ErrorCode(102)
ZSTD_error_dstBuffer_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(104)
ZSTD_error_srcBuffer_wrong → const ZSTD_ErrorCode
const ZSTD_ErrorCode(105)
ZSTD_error_sequenceProducer_failed → const ZSTD_ErrorCode
const ZSTD_ErrorCode(106)
ZSTD_error_externalSequences_invalid → const ZSTD_ErrorCode
const ZSTD_ErrorCode(107)
ZSTD_error_maxCode → const ZSTD_ErrorCode

never EVER use this value directly, it can change in future versions! Use ZSTD_isError() instead

const ZSTD_ErrorCode(120)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ZSTD_ErrorCode

Constants

values → const List<ZSTD_ErrorCode>
A constant List of the values in this enum, in order of their declaration.