ZSTD_ErrorCode class abstract

-********************************************* Error codes list -********************************************* Error codes values are pinned down since v1.3.1 only. Therefore, don't rely on values if you may link to any version < v1.3.1.

Only values < 100 are considered stable.

note 1 : this API shall be used with static linking only. dynamic linking is not yet officially supported. note 2 : Prefer relying on the enum than on its value whenever possible This is the only supported way to use the error list < v1.3.1 note 3 : ZSTD_isError() is always correct, whatever the library version.

Constructors

ZSTD_ErrorCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ZSTD_error_cannotProduce_uncompressedBlock → const int
ZSTD_error_checksum_wrong → const int
ZSTD_error_corruption_detected → const int
ZSTD_error_dictionary_corrupted → const int
ZSTD_error_dictionary_wrong → const int
ZSTD_error_dictionaryCreation_failed → const int
ZSTD_error_dstBuffer_null → const int
ZSTD_error_dstBuffer_wrong → const int
ZSTD_error_dstSize_tooSmall → const int
ZSTD_error_externalSequences_invalid → const int
ZSTD_error_frameIndex_tooLarge → const int
following error codes are NOT STABLE, they can be removed or changed in future versions
ZSTD_error_frameParameter_unsupported → const int
ZSTD_error_frameParameter_windowTooLarge → const int
ZSTD_error_GENERIC → const int
ZSTD_error_init_missing → const int
ZSTD_error_literals_headerWrong → const int
ZSTD_error_maxCode → const int
never EVER use this value directly, it can change in future versions! Use ZSTD_isError() instead
ZSTD_error_maxSymbolValue_tooLarge → const int
ZSTD_error_maxSymbolValue_tooSmall → const int
ZSTD_error_memory_allocation → const int
ZSTD_error_no_error → const int
ZSTD_error_noForwardProgress_destFull → const int
ZSTD_error_noForwardProgress_inputEmpty → const int
ZSTD_error_parameter_combination_unsupported → const int
ZSTD_error_parameter_outOfBound → const int
ZSTD_error_parameter_unsupported → const int
ZSTD_error_prefix_unknown → const int
ZSTD_error_seekableIO → const int
ZSTD_error_sequenceProducer_failed → const int
ZSTD_error_srcBuffer_wrong → const int
ZSTD_error_srcSize_wrong → const int
ZSTD_error_stabilityCondition_notRespected → const int
ZSTD_error_stage_wrong → const int
ZSTD_error_tableLog_tooLarge → const int
ZSTD_error_version_unsupported → const int
ZSTD_error_workSpace_tooSmall → const int