ZSTD_strategy enum

Compression strategies, listed from fastest to strongest

Inheritance
Available extensions

Values

ZSTD_fast → const ZSTD_strategy
const ZSTD_strategy(1)
ZSTD_dfast → const ZSTD_strategy
const ZSTD_strategy(2)
ZSTD_greedy → const ZSTD_strategy
const ZSTD_strategy(3)
ZSTD_lazy → const ZSTD_strategy
const ZSTD_strategy(4)
ZSTD_lazy2 → const ZSTD_strategy
const ZSTD_strategy(5)
ZSTD_btlazy2 → const ZSTD_strategy
const ZSTD_strategy(6)
ZSTD_btopt → const ZSTD_strategy
const ZSTD_strategy(7)
ZSTD_btultra → const ZSTD_strategy
const ZSTD_strategy(8)
ZSTD_btultra2 → const ZSTD_strategy
const ZSTD_strategy(9)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ZSTD_strategy

Constants

values → const List<ZSTD_strategy>
A constant List of the values in this enum, in order of their declaration.