zstandard_native_bindings
library
Enums
-
ZSTD_cParameter
-
-
ZSTD_dParameter
-
The advanced API pushes parameters one by one into an existing DCtx context.
Parameters are sticky, and remain valid for all following frames
using the same DCtx context.
It's possible to reset parameters to default values using ZSTD_DCtx_reset().
Note : This API is compatible with existing ZSTD_decompressDCtx() and ZSTD_decompressStream().
Therefore, no new decompression function is necessary.
-
ZSTD_EndDirective
-
===== Streaming compression functions =====
-
ZSTD_ErrorCode
-
-*********************************************
Error codes list
-*********************************************
Error codes values are pinned down since v1.3.1 only.
Therefore, don't rely on values if you may link to any version < v1.3.1.
-
ZSTD_ResetDirective
-
-
ZSTD_strategy
-
Compression strategies, listed from fastest to strongest
Typedefs
-
ZSTD_CCtx
= ZSTD_CCtx_s
-
Explicit context
/
/*= Compression context
When compressing many times,
it is recommended to allocate a compression context just once,
and reuse it for each successive compression operation.
This will make the workload easier for system's memory.
Note : re-using context is just a speed / resource optimization.
It doesn't change the compression ratio, which remains identical.
Note 2: For parallel execution in multi-threaded environments,
use one different context per thread .
-
ZSTD_CDict
= ZSTD_CDict_s
-
Bulk processing dictionary API
-
ZSTD_CStream
= ZSTD_CCtx
-
-***********************************************************************
Streaming compression - HowTo
-
ZSTD_DCtx
= ZSTD_DCtx_s
-
= Decompression context
When decompressing many times,
it is recommended to allocate a context only once,
and reuse it for each successive compression operation.
This will make workload friendlier for system's memory.
Use one context per thread for parallel execution.
-
ZSTD_DDict
= ZSTD_DDict_s
-
-
ZSTD_DStream
= ZSTD_DCtx
-
-***************************************************************************
Streaming decompression - HowTo
-
ZSTD_inBuffer
= ZSTD_inBuffer_s
-
-
ZSTD_outBuffer
= ZSTD_outBuffer_s
-